<?php
/**
 *  Index.php
 *
 *  @author    {$author}
 *  @package   {$project_id}
 *  @version   $Id: app.action.default.php 728 2009-02-05 18:36:10Z mumumu-org $
 */

/**
 *  indexեμ
 *
 *  @author    {$author}
 *  @access    public
 *  @package   {$project_id}
 */

class {$project_id}_Form_Index extends {$project_id}_ActionForm
{
    /** @var    bool    Хǡ˥ץ饰Ȥե饰 */
    var $use_validator_plugin = true;

    /**
     *  @access   private
     *  @var      array   ե
     */
     var $form = array(
       /*
        *  TODO: Υ󤬻Ѥե򵭽ҤƤ
        *
        *  (typeƤǤϾάǽ)
        *
        *  'sample' => array(
        *  // ե
        *      'type'        => VAR_TYPE_INT,        // ͷ
        *      'form_type'   => FORM_TYPE_TEXT,      // ե෿
        *      'name'        => 'ץ',          // ɽ̾
        *  
        *  // Хǡ(ҽ˥Хǡ¹Ԥޤ)
        *      'required'    => true,                        // ɬܥץ(true/false)
        *      'min'         => null,                        // Ǿ
        *      'max'         => null,                        // 
        *      'regexp'      => null,                        // ʸ(ɽ)
        *
        *  // ե륿
        *      'filter'      => null,                        // Ѵե륿ץ
        *  ),
        */
      );
}

/**
 *  indexμ
 *
 *  @author     {$author}
 *  @access     public
 *  @package    {$project_id}
 */
class {$project_id}_Action_Index extends {$project_id}_ActionClass
{
        /**
         *  index
         *
         *  @access    public
         *  @return    string  Forward(ｪλʤnull)
         */
        function prepare()
        {
                return null;
        }

        /**
         *  indexμ
         *
         *  @access    public
         *  @return    string  ̾
         */
        function perform()
        {
                return 'index';
        }
}
?>
